@@ -1,7 +1,7 @@
 package Perinci::Sub::ConvertArgs::Argv;
 
 our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -79,10 +79,21 @@ sub convert_args_to_argv {
     my %iargs = %$iargs; # copy 'coz we will delete them one by one as we fill
 
     if ($fargs{use_pos}) {
-        for (sort {$args_prop->{$a}{pos} <=> $args_prop->{$b}{pos}}
-                 grep {defined $args_prop->{$_}{pos}} keys %iargs) {
-            $argv[ $args_prop->{$_}{pos} ] = _encode($iargs{$_});
-            delete $iargs{$_};
+        for my $arg (sort {$args_prop->{$a}{pos} <=> $args_prop->{$b}{pos}}
+                         grep {defined $args_prop->{$_}{pos}} keys %iargs) {
+            my $pos = $args_prop->{$arg}{pos};
+            if ($args_prop->{$arg}{greedy}) {
+                my $sch = $args_prop->{$arg}{schema};
+                my $is_array_of_simple = $sch && $sch->[0] eq 'array' &&
+                    $sch->[1]{of} && is_simple($sch->[1]{of});
+                for my $el (@{ $iargs{$arg} }) {
+                    $argv[$pos] = $is_array_of_simple ? $el : _encode($el);
+                    $pos++;
+                }
+            } else {
+                $argv[$pos] = _encode($iargs{$arg});
+            }
+            delete $iargs{$arg};
         }
     }
 
@@ -133,7 +144,7 @@ Perinci::Sub::ConvertArgs::Argv - Convert hash arguments to command-line options
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2015-12-17.
+This document describes version 0.07 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
